@@ -115,6 +115,7 @@ main (
   for (i = 1; i < argc; i++)
   {
     if (strcmp(argv[i], "-") == 0)           { continue; }
+    if (strcmp(argv[i], "--") == 0)          { continue; }
     if((strcmp(argv[i], "-i") == 0)
     || (strcmp(argv[i], "--input") == 0))    { continue; }
     if (strcmp(argv[i], "--version") == 0)   { version(); }
@@ -360,8 +361,9 @@ APPNAME ") " VERSION "\n"
 "This program comes with ABSOLUTELY NO WARRANTY; not even for MERCHANTABILITY\n"
 "or FITNESS FOR A PARTICULAR PURPOSE. This program is licensed under the\n"
 "terms of the GNU GPL version 3 or any later version as published by the Free\n"
-"Software Foundation. User documentation is licensed under the Creative\n"
-"Commons Attribution-ShareAlike 3.0 license.\n"
+"Software Foundation. User documentation is alternatively licensed under the\n"
+"Creative Commons Attribution-ShareAlike license version 3 or a later\n"
+"version as published by the Creative Commons Corporation.\n"
 "\n"
 "Written by " AUTHORS "."
   );
